<?php
/**
 * @copyright	Copyright (c) 2015 Emiel Kwakkel (http://emielkwakkel.nl). All rights reserved.
 * @license		GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

/**
 * Emiel Kwakkel Articles Count Helper Class.
 *
 * @package		Joomla.Site
 * @subpackage	articles_count.modArticlesCount
 */
class modArticlesCount extends JFactory {
	private $db; // Variable for database connection
	private $query; // Variable to hold the query
	
	public function __construct()
	{
		// Get a db connection.
		$this->db = JFactory::getDbo();
		
		// Create a new query object.
		$this->query = $this->db->getQuery(true);
	}
	
	public function excludeCategories($category_exclude)
	{
		// Check if there are any categories to exclude
		if($category_exclude != "")
		{
			// Create array from list of excluded categories
			$category_exclude = explode(',', $category_exclude);
			
			// For each excluded category add a where statement to the query
			foreach ($category_exclude as $categories => $category) 
			{
				$this->query->where($this->db->quoteName('catid') . ' != ' . $category[0]);
			}
		}
	}
	
	public function countArticlesTotal($category_exclude)
	{
		// Clear the current query
		$this->query->clear();
		
		// Counts all published articles from __content
		$this->query
			->select(array('COUNT(*)'))
		    ->where($this->db->quoteName('state') . ' LIKE 1')
		    ->from($this->db->quoteName('#__content'));
		    
		// Use excludeCategories function to add where statements to the query if there are categories to exclude.
		$this->excludeCategories($category_exclude);
		
		// Reset the query using our newly populated query object.
		$this->db->setQuery($this->query);
		 
		// Load the results in a Row
		$result = $this->db->loadRowList();

		return $result[0][0];
	}
	
	public function countArticlesCategory($category_exclude, $category_sort = 'b.title', $category_order = 'ASC', $category_limit = 0)
	{
		// Clear the current query
		$this->query->clear();
		
		// Selects all category titles and counts the number of published articles within that category
		$this->query
			->select(array('b.title', 'COUNT(*)', 'b.path') )
			->from($this->db->quoteName('#__content','a'))
			->group($this->db->quoteName('catid'))
			->where($this->db->quoteName('a.state') . ' LIKE 1')
			->join('INNER', $this->db->quoteName('#__categories', 'b') . ' ON (' . $this->db->quoteName('a.catid') . ' = ' . $this->db->quoteName('b.id') . ')')
			->order($category_sort . " " . $category_order);
		
		// If limit is not zero (unlimited) then add the limit to the query
		if ($category_limit != 0) {
			$this->query->setLimit($category_limit);
		}
		
		// Use excludeCategories function to add where statements to the query if there are categories to exclude.
		$this->excludeCategories($category_exclude);
		
		// Reset the query using our newly populated query object.
		$this->db->setQuery($this->query);
		 
		// Return the results in a single object
		return $this->db->loadRowList();
	}
	
	
	public static function sanitizeCategory($input)
	{
		// Strips the string from all characters except integers and comma (,)
		return trim($input, "abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ!@#$%^&*()-=_+{}:\"|;'\<>?./±§ ");
	}
	
	public static function htmlChars($parameter)
	{
		return  htmlspecialchars($parameter);
	}
	
}